@@ -4,6 +4,9 @@
 #' on a variety of categories, such as: establishments, prominent points of interest,
 #' geographic locations, and more.
 #'
+#' A Nearby Search (using \code{google_places}) lets you search for places within a specified area.
+#' You can refine your search request by supplying keywords or specifying the type of place you are searching for.
+#'
 #' @note
 #' The Google Places API Web Service enforces a default limit of 1,000 free requests
 #' per 24 hour period, calculated as the sum of client-side and server-side requets.
@@ -16,21 +19,13 @@
 #' @param search_string \code{string} A search term representing a place for
 #' which to search. If blank, the \code{location} argument must be used.
 #' @param location \code{numeric} vector of latitude/longitude coordinates
-#' (in that order) around which to retrieve place information. If \code{NULL}, the
-#' \code{search_string} argument must be used. If used in conjunction with
-#' \code{search_string} it represents the latitude/longitude around which to
-#' retrieve place information.
-#' @param radar \code{boolean} The Google Places API Radar Search Service allows
-#' you to search for up to 200 places at once, but with less detail than is typically
-#' returned from a Text Search (\code{search_string}) or Nearby Search (\code{location}) request.
-#' A radar search must contain a \code{location} and \code{radius}, and one of \code{keyword},
-#' \code{name} or \code{type}. A radar search will not use a \code{search_string}
+#' (in that order) around which to retrieve place information.
 #' @param radius \code{numeric} Defines the distance (in meters) within which to
 #' return place results. Required if only a \code{location} search is specified.
 #' The maximum allowed radius is 50,000 meters. Radius must not be included if
-#' \code{rankby="distance"} is specified. see Details.
+#' \code{rankby} is used. see Details.
 #' @param rankby \code{string} Specifies the order in which results are listed.
-#' Possible values are \code{"prominence"}, \code{"distance"} or \code{"location"}.
+#' Possible values are \code{"prominence"} or \code{"distance"}.
 #' If \code{rankby = distance}, then one of \code{keyword}, \code{name} or
 #' \code{place_type} must be specified. If a \code{search_string} is used then
 #' \code{rankby} is ignored.
@@ -67,13 +62,13 @@
 #' into a list.
 #' @param curl_proxy a curl proxy object
 #' @param key \code{string} A valid Google Developers Places API key.
+#' @param radar deprecated, no longer used
 #'
 #' @details
-#' With the Places service you can perform four kinds of searches:
+#' With the Places service you can perform three kinds of searches:
 #' \itemize{
 #'   \item{Nearby Search}
 #'   \item{Text Search}
-#'   \item{Radar Sarch}
 #'   \item{Place Details request}
 #' }
 #'
@@ -86,10 +81,6 @@
 #' The service responds with a list of places matching the string and any location
 #' bias that has been set.
 #'
-#' A Radar search lets you search for places within a specified search radius
-#' by keyword, type or name. The Radar search returns more results than a
-#' Nearby or Text search, but the results contain fewer fields.
-#'
 #' A Place Detail search (using \link{google_place_details}) can be performed when
 #' you have a given \code{place_id}
 #' from one of the other three search methods.
@@ -108,7 +99,7 @@
 #'
 #' @inheritSection google_geocode API use and limits
 #'
-#' @seealso \link{google_place_details}
+#' @seealso \link{google_place_details} \link{google_find_place}
 #'
 #' @examples
 #' \dontrun{
@@ -138,22 +129,24 @@
 #' }
 #' @export
 #'
-google_places <- function(search_string = NULL,
-                          location = NULL,
-                          radar = FALSE,
-                          radius = NULL,
-                          rankby = NULL,
-                          keyword = NULL,
-                          language = NULL,
-                          name = NULL,
-                          place_type = NULL,
-                          price_range = NULL,
-                          open_now = NULL,
-                          page_token = NULL,
-                          simplify = TRUE,
-                          curl_proxy = NULL,
-                          key = get_api_key("places")
-                          ){
+google_places <- function(
+  search_string = NULL,
+  location = NULL,
+  #radar = FALSE,
+  radius = NULL,
+  rankby = NULL,
+  keyword = NULL,
+  language = NULL,
+  name = NULL,
+  place_type = NULL,
+  price_range = NULL,
+  open_now = NULL,
+  page_token = NULL,
+  simplify = TRUE,
+  curl_proxy = NULL,
+  key = get_api_key("places"),
+  radar = NULL
+  ) {
 
   ## check if both search_string & location == NULL
   if(is.null(search_string) & is.null(location))
@@ -163,15 +156,14 @@ google_places <- function(search_string = NULL,
     location <- validateGeocodeLocation(location)
   }
 
-  logicalCheck(radar)
   logicalCheck(simplify)
   logicalCheck(open_now)
 
-  radar <- validateRadar(radar, search_string, keyword, name, place_type, location, radius)
   location <- validateLocationSearch(location, search_string, radius, rankby, keyword, name, place_type)
   radius <- validateRadius(radius)
   rankby <- validateRankBy(rankby, location, search_string)
   radius <- validateRadiusRankBy(rankby, radius, location)
+  validateRadar( radar )
 
   language <- validateLanguage(language)
   name <- validateName(name, search_string)
@@ -182,30 +174,166 @@ google_places <- function(search_string = NULL,
   ## construct the URL
   ## if search string is specified, use the 'textsearch' url
   ## if no search_string, use the 'lat/lon' url
-  if(isTRUE(radar)){
-    map_url <- "https://maps.googleapis.com/maps/api/place/radarsearch/json?"
+  if(!is.null(search_string)){
+    search_string <- gsub(" ", "+", search_string)
+    map_url <- paste0("https://maps.googleapis.com/maps/api/place/textsearch/json?query=", search_string)
   }else{
-    if(!is.null(search_string)){
-      search_string <- gsub(" ", "+", search_string)
-      map_url <- paste0("https://maps.googleapis.com/maps/api/place/textsearch/json?query=", search_string)
-    }else{
-      map_url <- paste0("https://maps.googleapis.com/maps/api/place/nearbysearch/json?")
-    }
+    map_url <- paste0("https://maps.googleapis.com/maps/api/place/nearbysearch/json?")
   }
 
-  map_url <- constructURL(map_url, c("location" = location,
-                                     "radius" = radius,
-                                     "rankby" = rankby,
-                                     "keyword" = keyword,
-                                     "language" = language,
-                                     "name" = name,
-                                     "type" = place_type,
-                                     "minprice" = price_range[1],
-                                     "maxprice" = price_range[2],
-                                     "opennow" = open_now,
-                                     "pagetoken" = page_token,
-                                     "key" = key))
-
-  return(downloadData(map_url, simplify, curl_proxy))
+  map_url <- constructURL(
+    map_url
+    , c("location" = location
+        , "radius" = radius
+        , "rankby" = rankby
+        , "keyword" = keyword
+        , "language" = language
+        , "name" = name
+        , "type" = place_type
+        , "minprice" = price_range[1]
+        , "maxprice" = price_range[2]
+        , "opennow" = open_now
+        , "pagetoken" = page_token
+        , "key" = key
+        )
+    )
 
+  return(
+    downloadData(map_url, simplify, curl_proxy)
+    )
 }
+
+
+
+#' Google Find Place
+#'
+#' A Find Place request takes a text input, and returns a place.
+#' The text input can be any kind of Places data, for example, a name, address, or phone number
+#'
+#'
+#' @inheritParams google_places
+#' @param input The text input specifying which place to search for
+#' (for example, a name, address, or phone number).
+#' @param inputtype The type of input. This can be one of either textquery or phonenumber.
+#' Phone numbers must be in international format (prefixed by a plus sign ("+"),
+#' followed by the country code, then the phone number itself).
+#' @param fields vector of place data types to return. All Basic fields are returned by default.
+#' See details
+#' @param point vector of lat & lon values. Prefer results near this point.
+#' @param circle list of two elements, point (vector of lat & lon) and radius.
+#' Prefer results in this circle. Ignored if point is supplied
+#' @param rectangle list of two elements, sw (vector of lat & lon) and ne (vector of lat & lon)
+#' specifying the south-west and north-east bounds of a rectangle. Prefer results
+#' in this rectangle. Ignored if either point or circle are supplied
+#'
+#' @details
+#'
+#' Fields correspond to place search results
+#'  \url{https://developers.google.com/places/web-service/search#PlaceSearchResults}
+#' and are divided into three billing categories: Basic, Contact and Atmosphere.
+#'
+#' Basic fields are billed at base rate, and incur no additional charges. Contact
+#' and atmosphere fields are billed at a hihger rate. See pricing sheet for more information
+#' \url{https://cloud.google.com/maps-platform/pricing/sheet/?__utma=102347093.1187532699.1510801584.1537138439.1537138439.1&__utmb=102347093.0.10.1537138439&__utmc=102347093&__utmx=-&__utmz=102347093.1537138439.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)&__utmv=-&__utmk=133826830&_ga=2.227832157.1738618203.1537137400-1187532699.1510801584}
+#'
+#' \itemize{
+#'  \item{Basic - }{formatted_address, geometry, icon, id, name, permanently_closed, photos, place_id, plus_code, types}
+#'  \item{Contact - }{opening_hours}
+#'  \item{Atmosphere - }{price_level, rating}
+#' }
+#'
+#' @seealso \link{google_place_details} \link{google_places}
+#'
+#' @examples
+#' \donttest{
+#'
+#' ## specifying fields
+#' google_find_place(
+#'   input = "Museum of Contemporary Art Australia"
+#'   , fields = c("photos","formatted_address","name","rating","opening_hours","geometry")
+#' )
+#'
+#' ## Using location bias - circle
+#' google_find_place(
+#'   input = "Mongolian Grill"
+#'   , circle = list(point = c(47.7, -122.2), radius = 2000)
+#' )
+#'
+#' ## finding by a phone number
+#' google_find_place(
+#'  input = "+61293744000"
+#'  , inputtype = "phonenumber"
+#' )
+#'
+#' }
+#'
+#' @export
+google_find_place <- function(
+  input,
+  inputtype = c("textquery","phonenumber"),
+  language = NULL,
+  fields = place_fields(),
+  point = NULL,
+  circle = NULL,
+  rectangle = NULL,
+  simplify = TRUE,
+  curl_proxy = NULL,
+  key = get_api_key("find_place")
+  ) {
+
+
+  inputtype <- match.arg(inputtype)
+  input <- validateFindInput( input, inputtype )
+
+  logicalCheck(simplify)
+
+
+  fields <- paste0(fields, collapse = ",")
+  point <- validateLocationPoint( point )
+  circle <- validateLocationCircle( circle )
+  rectangle <- validateLocationRectangle( rectangle )
+  locationbias <- validateLocationBias(point, circle, rectangle)
+
+  input <- gsub(" ", "+", input)
+  map_url <- paste0("https://maps.googleapis.com/maps/api/place/findplacefromtext/json?input=", input)
+
+  map_url <- constructURL(
+    map_url
+    , c("inputtype" = inputtype
+        , "fields" = fields
+        , "language" = language
+        , "locationbias" = locationbias
+        , "key" = key
+    )
+  )
+
+  return(
+    downloadData(map_url, simplify, curl_proxy)
+  )
+}
+
+
+#' Place Fields
+#'
+#' Convenience function to return all the valid basic field values for use in a \link{google_find_place}
+#' search
+#'
+#' @export
+place_fields <- function() {
+  return(
+    c(
+      "formatted_address"
+      ,"geometry"
+      ,"icon"
+      ,"id"
+      ,"name"
+      ,"permanently_closed"
+      ,"photos"
+      ,"place_id"
+      ,"plus_code"
+      #,"scope"  ## this causes invalid request from Google
+      ,"types"
+      )
+    )
+}
+
